@@ -5,12 +5,13 @@ use warnings;
 package Story::Interact::Harness;
 
 our $AUTHORITY = 'cpan:TOBYINK';
-our $VERSION   = '0.001009';
+our $VERSION   = '0.001010';
 
 use Story::Interact::State ();
 
 use Moo::Role;
 use Types::Common -types;
+use URI::Query ();
 use namespace::clean;
 
 use constant DEBUG       => !!$ENV{PERL_STORY_INTERACT_DEBUG};
@@ -30,7 +31,18 @@ has 'page_source' => (
 
 sub get_page {
 	my ( $self, $page_id ) = @_;
-	return $self->page_source->get_page( $self->state, $page_id );
+	
+	my $state = $self->state;
+	if ( $page_id =~ /\A(.+)\?(.+)\z/ms ) {
+		$page_id = $1;
+		my $params = URI::Query->new( $2 )->hash;
+		$state->params( $params );
+	}
+	else {
+		$state->params( {} );
+	}
+	
+	return $self->page_source->get_page( $state, $page_id );
 }
 
 1;
